bayespy.inference.vmp.nodes.bernoulli.BernoulliDistribution.compute_cgf_from_parents
====================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.bernoulli

.. automethod:: BernoulliDistribution.compute_cgf_from_parents